"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const path_1 = tslib_1.__importDefault(require("path"));
const fs_1 = tslib_1.__importDefault(require("fs"));
const fs_2 = require("../lib/utils/fs");
const generate_env_1 = require("../lib/generate-env");
class GenEnv extends core_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = yield this.parse(GenEnv);
            const info = (0, generate_env_1.generateEnv)({
                sourceFilePath: flags['source-file'],
                options: { tsConfigFilePath: flags.tsconfig },
            });
            if (flags.output) {
                const tempstats = fs_1.default.statSync(flags.output);
                if (tempstats.isDirectory()) {
                    (0, fs_2.ensureDirSync)(flags.output);
                    const outputFilePath = path_1.default.join(flags.output, '.env');
                    fs_1.default.writeFileSync(outputFilePath, info.join('\n'));
                    console.log(`output file: ${outputFilePath}`);
                }
                else {
                    const folderPath = path_1.default.parse(flags.output);
                    (0, fs_2.ensureDirSync)(folderPath.dir);
                    fs_1.default.writeFileSync(flags.output, info.join('\n'));
                    console.log(`output file: ${flags.output}`);
                }
            }
            else {
                console.log(info);
            }
        });
    }
}
exports.default = GenEnv;
GenEnv.description = 'Generate .env';
GenEnv.examples = [
    `$ typed-env gen-env -s ./src/index.ts -t ./tsconfig.json -o ./src/.env`,
];
GenEnv.flags = {
    'source-file': core_1.Flags.string({
        char: 's',
        description: 'enter the file path to check',
        required: true,
    }),
    tsconfig: core_1.Flags.string({
        char: 't',
        description: 'enter the tsconfig.json path',
        required: true,
    }),
    output: core_1.Flags.string({
        char: 'o',
        description: 'enter the output file path',
    }),
};
